@@ -413,45 +413,56 @@ GSwitchItAppletChangePixelSize (PanelApplet *
 	GSwitchItAppletRevalidate (sia);
 }
 
+static void 
+GSwitchItAppletSetBackground(PanelAppletBackgroundType type,
+			     GtkRcStyle * rc_style,
+			     GtkWidget * w, 
+			     GdkColor * color,
+			     GdkPixmap * pixmap)
+{
+	GtkStyle *style;
+
+	gtk_widget_set_style (GTK_WIDGET (w), NULL);
+	gtk_widget_modify_style (GTK_WIDGET (w), rc_style);
+
+	switch (type)
+	{
+	case PANEL_NO_BACKGROUND:
+	        break;
+	case PANEL_COLOR_BACKGROUND:
+	        gtk_widget_modify_bg (GTK_WIDGET (w),
+	                              GTK_STATE_NORMAL, color);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (w->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL])
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (w, style);
+		break;
+	}
+	/* go down */
+	if (GTK_IS_CONTAINER (w))
+	{
+		GList * child = gtk_container_get_children (GTK_CONTAINER (w));
+		while (child != NULL)
+		{
+			GSwitchItAppletSetBackground (type, rc_style,
+			     GTK_WIDGET (child->data), color, pixmap);
+			child = child->next;
+		}
+	}
+}
+
 static void
-GSwitchItAppletChangeBackground (PanelApplet *
-				 widget, PanelAppletBackgroundType type,
+GSwitchItAppletChangeBackground (PanelApplet * widget, 
+				 PanelAppletBackgroundType type,
 				 GdkColor * color, GdkPixmap * pixmap,
 				 GSwitchItApplet * sia)
 {
 	GtkRcStyle *rc_style = gtk_rc_style_new ();
-
-	switch (type) {
-	case PANEL_PIXMAP_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
-					 rc_style);
-		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
-					 rc_style);
-		break;
-
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg (GTK_WIDGET (sia->ebox),
-				      GTK_STATE_NORMAL, color);
-		gtk_widget_modify_bg (GTK_WIDGET (sia->applet),
-				      GTK_STATE_NORMAL, color);
-		break;
-
-	case PANEL_NO_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
-					 rc_style);
-		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
-					 rc_style);
-		break;
-
-	default:
-		gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
-					 rc_style);
-		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
-					 rc_style);
-		break;
-	}
-
-	gtk_rc_style_unref (rc_style);
+	GSwitchItAppletSetBackground(type, rc_style, sia->applet, color, pixmap);
+	g_object_unref (rc_style);
 }
 
 static gboolean
@@ -643,12 +654,10 @@ GSwitchItAppletSetupGroupsSubmenu (GSwitchItApplet * sia)
 	unsigned i, nGroups;
 	GSList *nameNode = globals.groupNames;
 	BonoboUIComponent *popup;
-	GSList *layout;
 	popup =
 	    panel_applet_get_popup_component (PANEL_APPLET (sia->applet));
-	XklDebug (160, "Registered group submenu\n");
-	nGroups = XklGetNumGroups ();
-	layout = globals.kbdConfig.layouts;
+	XklDebug (160, "Registering group submenu\n");
+	nGroups = g_slist_length (globals.groupNames);
 	for (i = 0; i < nGroups; i++) {
 		char verb[40];
 		BonoboUINode *node;
@@ -678,7 +687,6 @@ GSwitchItAppletSetupGroupsSubmenu (GSwitchItApplet * sia)
 			  "Registered group menu item \'%s\' as \'%s\'\n",
 			  verb, nameNode->data);
 		nameNode = g_slist_next (nameNode);
-		layout = g_slist_next (layout);
 	}
 }
 
