@@ -48,6 +48,7 @@ typedef struct _GSwitchItConfig {
 
 	/* private, transient */
 	GConfClient *confClient;
+	int configListenerId;
 } GSwitchItConfig;
 
 /*
@@ -61,6 +62,7 @@ typedef struct _GSwitchItKbdConfig {
 
 	/* private, transient */
 	GConfClient *confClient;
+	int configListenerId;
 } GSwitchItKbdConfig;
 
 /*
@@ -76,6 +78,7 @@ typedef struct _GSwitchItAppletConfig {
 	GConfClient *confClient;
 	GSList *images;
 	GtkIconTheme *iconTheme;
+	int configListenerId;
 } GSwitchItAppletConfig;
 
 /**
@@ -85,9 +88,9 @@ extern void GSwitchItConfigInit (GSwitchItConfig * config,
 				 GConfClient * confClient);
 extern void GSwitchItConfigTerm (GSwitchItConfig * config);
 
-extern void GSwitchItConfigLoad (GSwitchItConfig * config);
+extern void GSwitchItConfigLoadFromGConf (GSwitchItConfig * config);
 
-extern void GSwitchItConfigSave (GSwitchItConfig * config);
+extern void GSwitchItConfigSaveToGConf (GSwitchItConfig * config);
 
 extern gboolean GSwitchItConfigActivate (GSwitchItConfig * config);
 
@@ -114,17 +117,17 @@ extern void GSwitchItKbdConfigInit (GSwitchItKbdConfig * kbdConfig,
 				    GConfClient * confClient);
 extern void GSwitchItKbdConfigTerm (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigLoad (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigLoadFromGConf (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigSave (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigSaveToGConf (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigLoadSysBackup (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigLoadFromGConfBackup (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigSaveSysBackup (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigSaveToGConfBackup (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigLoadInitial (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigLoadFromXInitial (GSwitchItKbdConfig * kbdConfig);
 
-extern void GSwitchItKbdConfigLoadCurrent (GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItKbdConfigLoadFromXCurrent (GSwitchItKbdConfig * kbdConfig);
 
 extern void GSwitchItKbdConfigStartListen (GSwitchItKbdConfig * kbdConfig,
 					   GConfClientNotifyFunc func, 
@@ -157,46 +160,33 @@ extern const char *GSwitchItKbdConfigFormatFullLayout (const char *layoutDescr,
  * some of them require GSwitchItKbdConfig as well - 
  * for loading approptiate images
  */
-extern void GSwitchItAppletConfigInit (GSwitchItAppletConfig *
-				       appletConfig,
+extern void GSwitchItAppletConfigInit (GSwitchItAppletConfig * appletConfig,
 				       GConfClient * confClient);
-extern void GSwitchItAppletConfigTerm (GSwitchItAppletConfig *
-				       appletConfig);
+extern void GSwitchItAppletConfigTerm (GSwitchItAppletConfig * appletConfig);
 
-extern void GSwitchItAppletConfigLoad (GSwitchItAppletConfig *
-				       appletConfig);
-extern void GSwitchItAppletConfigSave (GSwitchItAppletConfig *
-				       appletConfig);
+extern void GSwitchItAppletConfigLoadFromGConf (GSwitchItAppletConfig * appletConfig);
+extern void GSwitchItAppletConfigSaveToGConf (GSwitchItAppletConfig * appletConfig);
 
 extern char
-*GSwitchItAppletConfigGetImagesFile (GSwitchItAppletConfig *
-				     appletConfig,
+*GSwitchItAppletConfigGetImagesFile (GSwitchItAppletConfig * appletConfig,
 				     GSwitchItKbdConfig * kbdConfig,
 				     int group);
 
-extern void GSwitchItAppletConfigLoadImages (GSwitchItAppletConfig *
-					     appletConfig,
-					     GSwitchItKbdConfig *
-					     kbdConfig);
-extern void GSwitchItAppletConfigFreeImages (GSwitchItAppletConfig *
-					     appletConfig);
+extern void GSwitchItAppletConfigLoadImages (GSwitchItAppletConfig * appletConfig,
+					     GSwitchItKbdConfig * kbdConfig);
+extern void GSwitchItAppletConfigFreeImages (GSwitchItAppletConfig * appletConfig);
 
 /* Should be updated on Applet/GConf and Kbd/GConf configuration change */
-extern void GSwitchItAppletConfigUpdateImages (GSwitchItAppletConfig *
-					       appletConfig,
-					       GSwitchItKbdConfig *
-					       kbdConfig);
+extern void GSwitchItAppletConfigUpdateImages (GSwitchItAppletConfig * appletConfig,
+					       GSwitchItKbdConfig * kbdConfig);
 
 /* Should be updated on Applet/GConf configuration change */
-extern void GSwitchItAppletConfigActivate (GSwitchItAppletConfig *
-					   appletConfig);
+extern void GSwitchItAppletConfigActivate (GSwitchItAppletConfig * appletConfig);
 
-extern void GSwitchItAppletConfigStartListen (GSwitchItAppletConfig *
-					      appletConfig,
-					      GConfClientNotifyFunc
-					      func, gpointer user_data);
+extern void GSwitchItAppletConfigStartListen (GSwitchItAppletConfig * appletConfig,
+					      GConfClientNotifyFunc func, 
+					      gpointer user_data);
 
-extern void GSwitchItAppletConfigStopListen (GSwitchItAppletConfig *
-					     appletConfig);
+extern void GSwitchItAppletConfigStopListen (GSwitchItAppletConfig * appletConfig);
 
 #endif
