@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 2 -*- */
 /* GNOME Volume Applet
  * Copyright (C) 2004 Ronald Bultje <rbultje@ronald.bitfreak.net>
  *
@@ -59,7 +60,8 @@ static void	gnome_volume_applet_orientation	(PanelApplet *applet,
 static void	gnome_volume_applet_size	(PanelApplet *applet,
 						 guint      size);
 
-static void	gnome_volume_applet_refresh	(GnomeVolumeApplet *applet);
+static void	gnome_volume_applet_refresh	(GnomeVolumeApplet *applet,
+						 gboolean           force_refresh);
 static gboolean	cb_check			(gpointer   data);
 
 static void	cb_volume			(GtkAdjustment *adj,
@@ -79,17 +81,19 @@ static void	cb_ui_event			(BonoboUIComponent *comp,
 						 Bonobo_UIComponent_EventType type,
 						 const gchar       *state_string,
 						 gpointer           data);
+static void	cb_theme_change                (GtkIconTheme *icon_theme,
+						gpointer      data);
 
 static PanelAppletClass *parent_class = NULL;
 static struct {
   gchar *filename;
   GdkPixbuf *pixbuf;
 } pix[] = {
-  { GNOME_PIXMAPSDIR "/mixer/volume-mute.png",   NULL },
-  { GNOME_PIXMAPSDIR "/mixer/volume-zero.png",   NULL },
-  { GNOME_PIXMAPSDIR "/mixer/volume-min.png",    NULL },
-  { GNOME_PIXMAPSDIR "/mixer/volume-medium.png", NULL },
-  { GNOME_PIXMAPSDIR "/mixer/volume-max.png",    NULL },
+  { "stock_volume-mute", NULL },
+  { "stock_volume-0",    NULL },
+  { "stock_volume-min",  NULL },
+  { "stock_volume-med",  NULL },
+  { "stock_volume-max",  NULL },
   { NULL, NULL }
 };
 
@@ -162,13 +166,33 @@ flip (GdkPixbuf *pix)
   }
 }
 
+static void
+init_pixbufs (GnomeVolumeApplet *applet)
+{
+  gint n;
+  
+  for (n = 0; pix[n].filename != NULL; n++) {
+    if (pix[n].pixbuf)
+      g_object_unref (pix[n].pixbuf);
+    
+    pix[n].pixbuf = gtk_icon_theme_load_icon (
+      	    applet->icon_theme,
+      	    pix[n].filename,
+      	    panel_applet_get_size (&applet->parent),
+      	    0,
+      	    NULL);
+    if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
+      flip (pix[n].pixbuf);
+    }
+  }
+}
+
 static void
 gnome_volume_applet_class_init (GnomeVolumeAppletClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *gtkwidget_class = GTK_WIDGET_CLASS (klass);
   PanelAppletClass *panelapplet_class = PANEL_APPLET_CLASS (klass);
-  gint n;
 
   parent_class = g_type_class_ref (PANEL_TYPE_APPLET);
 
@@ -183,20 +207,12 @@ gnome_volume_applet_class_init (GnomeVolumeAppletClass *klass)
   /* FIXME:
    * - style-set.
    */
-
-  /* init pixbufs */
-  for (n = 0; pix[n].filename != NULL; n++) {
-    pix[n].pixbuf = gdk_pixbuf_new_from_file (pix[n].filename, NULL);
-    if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
-      flip (pix[n].pixbuf);
-    }
-  }
 }
 
 static void
 gnome_volume_applet_init (GnomeVolumeApplet *applet)
 {
-  GtkWidget *image, *dock;
+  GtkWidget *image;
   GtkTooltips *tooltips;
 
   applet->timeout = 0;
@@ -207,12 +223,17 @@ gnome_volume_applet_init (GnomeVolumeApplet *applet)
   applet->lock = FALSE;
   applet->state = -1;
   applet->prefs = NULL;
+  applet->icon_theme = gtk_icon_theme_get_default ();
+
+  /* init pixbufs */
+  init_pixbufs (applet);
 
   /* icon (our main UI) */
   image = gtk_image_new ();
   applet->image = GTK_IMAGE (image);
   gtk_container_add (GTK_CONTAINER (applet), image);
   gtk_widget_show (image);
+  gtk_window_set_default_icon_name ("volume-knob");
 
   /* dock window (expanded UI) */
   applet->pop = FALSE;
@@ -222,6 +243,11 @@ gnome_volume_applet_init (GnomeVolumeApplet *applet)
   gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),
 			_("Volume Control"), NULL);
 
+  /* handle icon theme changes */
+  g_signal_connect (G_OBJECT (applet->icon_theme),
+		    "changed", G_CALLBACK (cb_theme_change),
+		    applet);
+
   /* other stuff */
   panel_applet_add_preferences (PANEL_APPLET (applet),
 				"/schemas/apps/mixer_applet/prefs",
@@ -249,6 +275,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
     BONOBO_UI_UNSAFE_VERB ("Pref",     cb_verb),
     BONOBO_UI_VERB_END
   };
+  gchar *key;
 
   /* default element to first */
   g_return_if_fail (elements != NULL);
@@ -257,7 +284,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   applet->elements = elements;
 
   /* get active element, if any (otherwise we use the default) */
-  if ((value = gconf_client_get (applet->client,
+  if ((value = panel_applet_gconf_get_value (PANEL_APPLET (applet),
 				 GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT,
 				 NULL)) != NULL &&
       value->type == GCONF_VALUE_STRING) {
@@ -286,7 +313,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
    */
 
   /* get active track, if any (otherwise we use the default) */
-  if ((value = gconf_client_get (applet->client,
+  if ((value = panel_applet_gconf_get_value (PANEL_APPLET (applet),
 				 GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK,
 				 NULL)) != NULL &&
       value->type == GCONF_VALUE_STRING) {
@@ -326,7 +353,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   g_signal_connect (adj, "value-changed",
 		    G_CALLBACK (cb_volume), applet);
 
-  gnome_volume_applet_refresh (applet);
+  gnome_volume_applet_refresh (applet, FALSE);
   applet->timeout = g_timeout_add (100, cb_check, applet);
 
   /* menu - done here because bonobo is intialized now */
@@ -338,10 +365,20 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   g_signal_connect (component, "ui-event", G_CALLBACK (cb_ui_event), applet);
 
   /* gconf */
-  gconf_client_add_dir (applet->client, GNOME_VOLUME_APPLET_KEY_DIR,
+  key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
+				GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT);
+#if 0
+  gconf_client_add_dir (applet->client, key,
 			GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-  gconf_client_notify_add (applet->client, GNOME_VOLUME_APPLET_KEY_DIR,
+#endif
+  gconf_client_notify_add (applet->client, key,
 			   cb_gconf, applet, NULL, NULL);
+  g_free (key);
+  key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
+                                GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK);
+  gconf_client_notify_add (applet->client, key,
+                           cb_gconf, applet, NULL, NULL);
+  g_free (key);
 
   gtk_widget_show (GTK_WIDGET (applet));
 }
@@ -521,7 +558,7 @@ gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
 
   /* update graphic - this should happen automagically after the next
    * idle call, but apparently doesn't for some people... */
-  gnome_volume_applet_refresh (applet);
+  gnome_volume_applet_refresh (applet, FALSE);
 }
 
 /*
@@ -730,7 +767,8 @@ static void
 gnome_volume_applet_size (PanelApplet *applet,
 			  guint        size)
 {
-  gnome_volume_applet_refresh (GNOME_VOLUME_APPLET (applet));
+  init_pixbufs (GNOME_VOLUME_APPLET (applet));
+  gnome_volume_applet_refresh (GNOME_VOLUME_APPLET (applet), TRUE);
 
   if (PANEL_APPLET_CLASS (parent_class)->change_size)
     PANEL_APPLET_CLASS (parent_class)->change_size (applet, size);
@@ -797,14 +835,14 @@ cb_volume (GtkAdjustment *adj,
  * Automatic timer. Check for changes.
  */
 
-#define STATE(vol,m) ((vol << 1) | m)
+#define STATE(vol,m) ((vol << 1) | (m ? 1 : 0))
 
 static void
-gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
+gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
+			     gboolean           force_refresh)
 {
   BonoboUIComponent *component;
-  GdkPixbuf *scaled, *orig;
-  guint size;
+  GdkPixbuf *pixbuf;
   gint n, *volumes, volume = 0;
   gboolean mute;
 
@@ -830,25 +868,13 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
   if (n >= 5)
     n = 4;
 
-  if (STATE (n, mute) != applet->state) {
-    if (mute) {
-      orig = gdk_pixbuf_copy (pix[applet->state >> 1].pixbuf);
-      gdk_pixbuf_composite (pix[0].pixbuf, orig, 0, 0,
-			    gdk_pixbuf_get_width (orig),
-			    gdk_pixbuf_get_height (orig),
-			    0, 0, 1.0, 1.0,
-			    GDK_INTERP_BILINEAR, 255);
-    } else {
-      orig = pix[n].pixbuf;
-    }
-
-    size = panel_applet_get_size (PANEL_APPLET (applet));
-    scaled = gdk_pixbuf_scale_simple (orig, size, size,
-				      GDK_INTERP_BILINEAR);
-    gtk_image_set_from_pixbuf (applet->image, scaled);
+  if ((STATE (n, mute) != applet->state) || force_refresh) {
     if (mute)
-      gdk_pixbuf_unref (orig);
-    gdk_pixbuf_unref (scaled);
+      pixbuf = pix[0].pixbuf;
+    else
+      pixbuf = pix[n].pixbuf;
+
+    gtk_image_set_from_pixbuf (applet->image, pixbuf);
 
     applet->state = STATE (n, mute);
   }
@@ -868,7 +894,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
 static gboolean
 cb_check (gpointer data)
 {
-  gnome_volume_applet_refresh (GNOME_VOLUME_APPLET (data));
+  gnome_volume_applet_refresh (GNOME_VOLUME_APPLET (data), FALSE);
 
   return TRUE;
 }
@@ -885,16 +911,25 @@ cb_gconf (GConfClient *client,
 {
   GnomeVolumeApplet *applet = data;
   GConfValue *value;
-  const gchar *str;
+  const gchar *str, *key;
   const GList *item;
   GstMixerTrack *active_track = NULL;
   gboolean newdevice = FALSE;
+  gchar *keyroot;
+
+  keyroot = panel_applet_gconf_get_full_key (PANEL_APPLET (applet), "");
+  key = gconf_entry_get_key (entry);
+  if (strncmp (key, keyroot, strlen (keyroot))) {
+    g_free (keyroot);
+    return;
+  }
+  key += strlen (keyroot);
+  g_free (keyroot);
 
   if ((value = gconf_entry_get_value (entry)) != NULL &&
       (value->type == GCONF_VALUE_STRING) &&
       (str = gconf_value_get_string (value)) != NULL) {
-    if (!strcmp (gconf_entry_get_key (entry),
-		 GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT)) {
+    if (!strcmp (key, GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT)) {
       for (item = applet->elements; item != NULL; item = item->next) {
         gchar *cur_el_str = g_object_get_data (item->data,
 					       "gnome-volume-applet-name");
@@ -903,21 +938,23 @@ cb_gconf (GConfClient *client,
           GstElement *old_element = GST_ELEMENT (applet->mixer);
 
           /* change element */
-          gst_element_set_state (item->data, GST_STATE_READY);
+          if (gst_element_set_state (item->data,
+				GST_STATE_READY) != GST_STATE_SUCCESS)
+            continue;
           gst_object_replace ((GstObject **) &applet->mixer, item->data);
           gst_element_set_state (old_element, GST_STATE_NULL);
 
           newdevice = TRUE;
-          active_track = gst_mixer_list_tracks (applet->mixer)->data;
+          if (gst_mixer_list_tracks (applet->mixer)) {
+            active_track = gst_mixer_list_tracks (applet->mixer)->data;
+          }
           str = applet->track->label;
           break;
         }
       }
     }
 
-    if (!strcmp (gconf_entry_get_key (entry),
-		 GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK) ||
-        newdevice) {
+    if (!strcmp (key, GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK) || newdevice) {
       for (item = gst_mixer_list_tracks (applet->mixer);
            item != NULL; item = item->next) {
         GstMixerTrack *track = item->data;
@@ -1017,14 +1054,14 @@ cb_verb (BonoboUIComponent *uic,
 				  "applet"),
 		"authors",	authors,
 		"translator-credits",	_("translator-credits"),
-		"logo-icon-name",	"gnome-mixer-applet",
+		"logo-icon-name",	"volume-knob",
 		NULL);
 
   } else if (!strcmp (verbname, "Pref")) {
     if (applet->prefs)
       return;
 
-    applet->prefs = gnome_volume_applet_preferences_new (applet->client,
+    applet->prefs = gnome_volume_applet_preferences_new (PANEL_APPLET (applet),
 							 applet->elements,
 							 applet->mixer,
 							 applet->track);
@@ -1057,3 +1094,13 @@ cb_ui_event (BonoboUIComponent *comp,
     g_warning ("Unknown bonobo command '%s'", verbname);
   }
 }
+
+static void
+cb_theme_change (GtkIconTheme *icon_theme,
+		 gpointer data)
+{
+  GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (data);
+
+  init_pixbufs (applet);
+  gnome_volume_applet_refresh (applet, TRUE);
+}
