@@ -24,8 +24,10 @@
 #define PROP_NET		2
 #define PROP_SWAP		3
 #define PROP_AVG		4
-#define PROP_SPEED		5
-#define PROP_SIZE		6
+#define PROP_DISK		5
+
+#define PROP_SPEED		6
+#define PROP_SIZE		7
 #define HIG_IDENTATION		"    "
 #define NEVER_SENSITIVE		"never_sensitive"
 
@@ -69,7 +71,7 @@ key_writable (PanelApplet *applet, const char *key)
 }
 
 
-void
+static void
 properties_set_insensitive(MultiloadApplet *ma)
 {
 	gint i, total_graphs, last_graph;
@@ -90,17 +92,36 @@ properties_set_insensitive(MultiloadApplet *ma)
 	return;
 }
 
-void
-properties_close_cb(GtkWidget *widget, gint arg, MultiloadApplet *ma)
+static void
+properties_close_cb (GtkWidget *widget, gint arg, MultiloadApplet *ma)
 {
-	gtk_widget_destroy(widget);
+	GError *error = NULL;
 
-	ma->prop_dialog = NULL;
+	switch (arg)
+	{
+		case GTK_RESPONSE_HELP:
 
-	return;
+		        gnome_help_display_on_screen (
+					"multiload", NULL,
+					gtk_widget_get_screen (GTK_WIDGET (
+							ma->applet)),
+					&error);
+
+			if (error) { /* FIXME: the user needs to see this */
+				g_warning ("help error: %s\n", error->message);
+				g_error_free (error);
+				error = NULL;
+			}
+			break;
+			
+		case GTK_RESPONSE_CLOSE:
+		default:
+			gtk_widget_destroy (widget);
+			ma->prop_dialog = NULL;
+	}
 }
 
-void
+static void
 property_toggled_cb(GtkWidget *widget, gpointer name)
 {
 	MultiloadApplet *ma;
@@ -136,7 +157,7 @@ property_toggled_cb(GtkWidget *widget, gpointer name)
 	return;
 }
 
-void
+static void
 spin_button_changed_cb(GtkWidget *widget, gpointer name)
 {
 	MultiloadApplet *ma;
@@ -195,7 +216,7 @@ spin_button_changed_cb(GtkWidget *widget, gpointer name)
 }
 
 /* create a new page in the notebook widget, add it, and return a pointer to it */
-GtkWidget *
+static GtkWidget *
 add_page(GtkWidget *notebook, gchar *label)
 {
 	GtkWidget *page;
@@ -211,7 +232,7 @@ add_page(GtkWidget *notebook, gchar *label)
 }
 
 /* save the selected color to gconf and apply it on the applet */
-void
+static void
 color_picker_set_cb(GtkColorButton *color_picker, gpointer data)
 {
 	gchar color_string[8];
@@ -235,6 +256,8 @@ color_picker_set_cb(GtkColorButton *color_picker, gpointer data)
 		prop_type = PROP_SWAP;
 	else if (strstr(gconf_path, "loadavg"))
 		prop_type = PROP_AVG;
+	else if (strstr(gconf_path, "diskload"))
+		prop_type = PROP_DISK;
 	else
 		g_assert_not_reached();
 		
@@ -253,7 +276,7 @@ color_picker_set_cb(GtkColorButton *color_picker, gpointer data)
 }
 
 /* create a color selector */
-void
+static void
 add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApplet *ma)
 {
 	GtkWidget *vbox;
@@ -296,7 +319,7 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 }
 
 /* creates the properties dialog using up-to-the-minute info from gconf */
-void
+static void
 fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 {
 	GtkWidget *notebook, *page;
@@ -420,6 +443,18 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	if ( ! key_writable (ma->applet, "view_loadavg"))
 		hard_set_sensitive (check_box, FALSE);
 
+	check_box = gtk_check_button_new_with_mnemonic(_("_Harddisk"));
+	ma->check_boxes[5] = check_box;
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_box),
+			panel_applet_gconf_get_bool (ma->applet,
+				"view_diskload", NULL));
+	g_object_set_data (G_OBJECT (check_box), "MultiloadApplet", ma);
+	g_object_set_data (G_OBJECT (check_box), "prop_type",
+			GINT_TO_POINTER (PROP_DISK));
+	g_signal_connect (G_OBJECT (check_box), "toggled",
+			G_CALLBACK (property_toggled_cb), "view_diskload");
+	gtk_box_pack_start (GTK_BOX (control_hbox), check_box, FALSE, FALSE, 0);
+
 	category_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (categories_vbox), category_vbox, TRUE, TRUE, 0);
 	gtk_widget_show (category_vbox);
@@ -562,7 +597,8 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	add_color_selector(page, _("_User"), "cpuload_color0", ma);
 	add_color_selector(page, _("S_ystem"), "cpuload_color1", ma);
 	add_color_selector(page, _("N_ice"), "cpuload_color2", ma);
-	add_color_selector(page, _("I_dle"), "cpuload_color3", ma);
+	add_color_selector(page, _("I_OWait"), "cpuload_color3", ma);
+	add_color_selector(page, _("I_dle"), "cpuload_color4", ma);
 	
 	page = add_page(notebook,  _("Memory"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
@@ -589,6 +625,12 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector(page, _("_Average"), "loadavg_color0", ma);
 	add_color_selector(page, _("_Background"), "loadavg_color1", ma);
+
+	page = add_page (notebook, _("Harddisk"));
+	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
+	add_color_selector (page, _("_Read"), "diskload_color0", ma);
+	add_color_selector (page, _("_Write"), "diskload_color1", ma);
+	add_color_selector (page, _("_Background"), "diskload_color2", ma);
 	
 	return;
 }
@@ -613,7 +655,8 @@ multiload_properties_cb (BonoboUIComponent *uic,
 	
 	dialog = gtk_dialog_new_with_buttons (_("System Monitor Preferences"),
 					      NULL, 0,
-					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					   GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+					   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
