@@ -27,7 +27,6 @@ StickyNotes *stickynotes = NULL;
 /* Popup menu on the applet */
 static const BonoboUIVerb stickynotes_applet_menu_verbs[] = 
 {
-        BONOBO_UI_UNSAFE_VERB ("create", menu_create_cb),
         BONOBO_UI_UNSAFE_VERB ("destroy_all", menu_destroy_all_cb),
         BONOBO_UI_UNSAFE_VERB ("preferences", menu_preferences_cb),
         BONOBO_UI_UNSAFE_VERB ("help", menu_help_cb),
@@ -112,7 +111,8 @@ stickynotes_make_prelight_icon (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 
 
 /* Create and initalize global sticky notes instance */
-void stickynotes_applet_init(PanelApplet *panel_applet)
+void
+stickynotes_applet_init (PanelApplet *panel_applet)
 {	
 	GnomeIconTheme *icon_theme;
 	gchar *sticky_icon;
@@ -124,24 +124,28 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 	stickynotes->applets = NULL;
 
 	icon_theme = gnome_icon_theme_new ();
-	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme, "stock_notes", 48, NULL, NULL);
+	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme,
+			"stock_notes", 48, NULL, NULL);
 	/* Register size for icons */
 	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
-	
 
 	if (sticky_icon) {
-		gnome_window_icon_set_default_from_file(sticky_icon);
-		stickynotes->icon_normal = gdk_pixbuf_new_from_file(sticky_icon, NULL);
+		gnome_window_icon_set_default_from_file (sticky_icon);
+		stickynotes->icon_normal = gdk_pixbuf_new_from_file (
+				sticky_icon, NULL);
 	}
 	g_free (sticky_icon);
 	g_object_unref (icon_theme);
 
-	stickynotes->icon_prelight = gdk_pixbuf_new(gdk_pixbuf_get_colorspace (stickynotes->icon_normal),
-						    gdk_pixbuf_get_has_alpha (stickynotes->icon_normal),
-						    gdk_pixbuf_get_bits_per_sample (stickynotes->icon_normal),
-						    gdk_pixbuf_get_width (stickynotes->icon_normal),
-						    gdk_pixbuf_get_height (stickynotes->icon_normal));
-	stickynotes_make_prelight_icon (stickynotes->icon_prelight, stickynotes->icon_normal, 30);
+	stickynotes->icon_prelight = gdk_pixbuf_new (
+			gdk_pixbuf_get_colorspace (stickynotes->icon_normal),
+			gdk_pixbuf_get_has_alpha (stickynotes->icon_normal),
+			gdk_pixbuf_get_bits_per_sample (
+				stickynotes->icon_normal),
+			gdk_pixbuf_get_width (stickynotes->icon_normal),
+			gdk_pixbuf_get_height (stickynotes->icon_normal));
+	stickynotes_make_prelight_icon (stickynotes->icon_prelight,
+			stickynotes->icon_normal, 30);
 	stickynotes->gconf = gconf_client_get_default();
 	stickynotes->tooltips = gtk_tooltips_new();
 
@@ -149,22 +153,29 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 	stickynotes_applet_init_prefs();
 
 	/* Watch GConf values */
-	gconf_client_add_dir(stickynotes->gconf, GCONF_PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/defaults", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
-	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/settings", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
+	gconf_client_add_dir (stickynotes->gconf, GCONF_PATH,
+			GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (stickynotes->gconf, GCONF_PATH "/defaults",
+			(GConfClientNotifyFunc) preferences_apply_cb,
+			NULL, NULL, NULL);
+	gconf_client_notify_add (stickynotes->gconf, GCONF_PATH "/settings",
+			(GConfClientNotifyFunc) preferences_apply_cb,
+			NULL, NULL, NULL);
 
 	client = gnome_master_client ();
 	gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
 
-	/* The help suggests this is automatic, but that seems to not be the case here. */
+	/* The help suggests this is automatic, but that seems to not be
+	 * the case here. */
 	gnome_client_connect (client);
 	gnome_client_flush (client);
 	
 	/* Load sticky notes */
-	stickynotes_load(gtk_widget_get_screen(GTK_WIDGET(panel_applet)));
+	stickynotes_load (gtk_widget_get_screen (GTK_WIDGET (panel_applet)));
 	
 	/* Auto-save every so minutes (default 5) */
-	g_timeout_add(1000 * 60 * gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/autosave_time", NULL),
+	g_timeout_add (1000 * 60 * gconf_client_get_int(stickynotes->gconf,
+				GCONF_PATH "/settings/autosave_time", NULL),
 		      (GSourceFunc) applet_save_cb, NULL);
 }
 
@@ -194,30 +205,62 @@ void stickynotes_applet_init_icons(void)
 
 void stickynotes_applet_init_prefs(void)
 {
-	stickynotes->prefs = glade_xml_new(GLADE_PATH, "preferences_dialog", NULL);
+	stickynotes->prefs = glade_xml_new (GLADE_PATH, "preferences_dialog",
+			NULL);
 
-	stickynotes->w_prefs = glade_xml_get_widget(stickynotes->prefs, "preferences_dialog");
-	stickynotes->w_prefs_width = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(glade_xml_get_widget(stickynotes->prefs, "width_spin")));
-	stickynotes->w_prefs_height= gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(glade_xml_get_widget(stickynotes->prefs, "height_spin")));
-	stickynotes->w_prefs_color = glade_xml_get_widget(stickynotes->prefs, "default_color");
-	stickynotes->w_prefs_sys_color = GTK_WIDGET(&GTK_CHECK_BUTTON(glade_xml_get_widget(stickynotes->prefs, "sys_color_check"))->toggle_button);
-	stickynotes->w_prefs_font = glade_xml_get_widget(stickynotes->prefs, "default_font");
-	stickynotes->w_prefs_sys_font = GTK_WIDGET(&GTK_CHECK_BUTTON(glade_xml_get_widget(stickynotes->prefs, "sys_font_check"))->toggle_button);
-	stickynotes->w_prefs_click = glade_xml_get_widget(stickynotes->prefs, "click_behavior_menu");
-	stickynotes->w_prefs_sticky = GTK_WIDGET(&GTK_CHECK_BUTTON(glade_xml_get_widget(stickynotes->prefs, "sticky_check"))->toggle_button);
-	stickynotes->w_prefs_force = GTK_WIDGET(&GTK_CHECK_BUTTON(glade_xml_get_widget(stickynotes->prefs, "force_default_check"))->toggle_button);
+	stickynotes->w_prefs = glade_xml_get_widget (stickynotes->prefs,
+			"preferences_dialog");
+	stickynotes->w_prefs_width = gtk_spin_button_get_adjustment (
+			GTK_SPIN_BUTTON (glade_xml_get_widget (
+					stickynotes->prefs, "width_spin")));
+	stickynotes->w_prefs_height = gtk_spin_button_get_adjustment (
+			GTK_SPIN_BUTTON (glade_xml_get_widget (
+					stickynotes->prefs, "height_spin")));
+	stickynotes->w_prefs_color = glade_xml_get_widget (stickynotes->prefs,
+			"default_color");
+	stickynotes->w_prefs_font_color = glade_xml_get_widget (
+			stickynotes->prefs,
+			"font_color");
+	stickynotes->w_prefs_sys_color = GTK_WIDGET (&GTK_CHECK_BUTTON (
+				glade_xml_get_widget (stickynotes->prefs,
+					"sys_color_check"))->toggle_button);
+	stickynotes->w_prefs_font = glade_xml_get_widget (stickynotes->prefs,
+			"default_font");
+	stickynotes->w_prefs_sys_font = GTK_WIDGET (&GTK_CHECK_BUTTON (
+				glade_xml_get_widget (stickynotes->prefs,
+					"sys_font_check"))->toggle_button);
+	stickynotes->w_prefs_sticky = GTK_WIDGET (&GTK_CHECK_BUTTON (
+				glade_xml_get_widget (stickynotes->prefs,
+					"sticky_check"))->toggle_button);
+	stickynotes->w_prefs_force = GTK_WIDGET (&GTK_CHECK_BUTTON (
+				glade_xml_get_widget (stickynotes->prefs,
+					"force_default_check"))->toggle_button);
 
-	g_signal_connect(G_OBJECT(stickynotes->w_prefs), "response", G_CALLBACK(preferences_response_cb), NULL);
-	g_signal_connect(G_OBJECT(stickynotes->w_prefs), "delete-event", G_CALLBACK(preferences_delete_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_width), "value-changed", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_height), "value-changed", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_sys_color), "toggled", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_sys_font), "toggled", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect(G_OBJECT(stickynotes->w_prefs_color), "color_set", G_CALLBACK(preferences_color_cb), NULL);
-	g_signal_connect(G_OBJECT(stickynotes->w_prefs_font), "font_set", G_CALLBACK(preferences_font_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_click), "changed", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_sticky), "toggled", G_CALLBACK(preferences_save_cb), NULL);
-	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_force), "toggled", G_CALLBACK(preferences_save_cb), NULL);
+	g_signal_connect (G_OBJECT (stickynotes->w_prefs), "response",
+			G_CALLBACK (preferences_response_cb), NULL);
+	g_signal_connect (G_OBJECT (stickynotes->w_prefs), "delete-event",
+			G_CALLBACK (preferences_delete_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT (stickynotes->w_prefs_width),
+			"value-changed",
+			G_CALLBACK (preferences_save_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT (stickynotes->w_prefs_height),
+			"value-changed",
+			G_CALLBACK (preferences_save_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT (stickynotes->w_prefs_sys_color),
+			"toggled",
+			G_CALLBACK (preferences_save_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT(stickynotes->w_prefs_sys_font),
+			"toggled", G_CALLBACK (preferences_save_cb), NULL);
+	g_signal_connect (G_OBJECT (stickynotes->w_prefs_color),
+			"color-set", G_CALLBACK (preferences_color_cb), NULL);
+	g_signal_connect (G_OBJECT (stickynotes->w_prefs_font_color),
+			"color-set", G_CALLBACK (preferences_color_cb), NULL);
+	g_signal_connect (G_OBJECT (stickynotes->w_prefs_font),
+			"font-set", G_CALLBACK (preferences_font_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT (stickynotes->w_prefs_sticky),
+			"toggled", G_CALLBACK (preferences_save_cb), NULL);
+	g_signal_connect_swapped (G_OBJECT (stickynotes->w_prefs_force),
+			"toggled", G_CALLBACK (preferences_save_cb), NULL);
 
 	{
 		GtkSizeGroup *group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
@@ -225,39 +268,69 @@ void stickynotes_applet_init_prefs(void)
 		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "width_label"));
 		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "height_label"));
 		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "color_label"));
-		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "click_label"));
 
 		g_object_unref(group);
 	}
 			
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "width_label"), FALSE);
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "width_spin"), FALSE);
+	if (!gconf_client_key_is_writable(stickynotes->gconf,
+				GCONF_PATH "/defaults/width", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "width_label"),
+				FALSE);
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "width_spin"),
+				FALSE);
 	}
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "height_label"), FALSE);
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "height_spin"), FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/height", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "height_label"),
+				FALSE);
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "height_spin"),
+				FALSE);
 	}
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "color_label"), FALSE);
-		gtk_widget_set_sensitive(stickynotes->w_prefs_color, FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/color", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "color_label"),
+				FALSE);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_color, FALSE);
 	}
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL))
-		gtk_widget_set_sensitive(stickynotes->w_prefs_sys_color, FALSE);
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "font_label"), FALSE);
-		gtk_widget_set_sensitive(stickynotes->w_prefs_font, FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/font_color", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "font_color_label"),
+				FALSE);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
+				FALSE);
 	}
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL))
-		gtk_widget_set_sensitive(stickynotes->w_prefs_sys_font, FALSE);
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "click_label"), FALSE);
-		gtk_widget_set_sensitive(stickynotes->w_prefs_click, FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/settings/use_system_color", NULL))
+		gtk_widget_set_sensitive (stickynotes->w_prefs_sys_color,
+				FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/font", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+					stickynotes->prefs, "font_label"),
+				FALSE);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_font, FALSE);
 	}
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL))
-		gtk_widget_set_sensitive(stickynotes->w_prefs_sticky, FALSE);
-	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL))
-		gtk_widget_set_sensitive(stickynotes->w_prefs_force, FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/settings/use_system_font", NULL))
+		gtk_widget_set_sensitive (stickynotes->w_prefs_sys_font,
+				FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/settings/sticky", NULL))
+		gtk_widget_set_sensitive (stickynotes->w_prefs_sticky, FALSE);
+	if (!gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/settings/force_default", NULL))
+		gtk_widget_set_sensitive (stickynotes->w_prefs_force, FALSE);
 
 	stickynotes_applet_update_prefs();
 }
@@ -278,6 +351,10 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
+	applet->popup_menu = NULL;
+	applet->menu_tip = NULL;
+	applet->menu_show = NULL;
+
 	/* Expand the applet for Fitts' law complience. */
 	panel_applet_set_flags(panel_applet, PANEL_APPLET_EXPAND_MINOR);
 
@@ -288,7 +365,10 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	stickynotes_applet_update_icon(applet);
 
 	/* Add the popup menu */
-	panel_applet_setup_menu_from_file(panel_applet, NULL, "GNOME_StickyNotesApplet.xml", NULL, stickynotes_applet_menu_verbs, applet);
+	panel_applet_setup_menu_from_file(panel_applet,
+			DATADIR, "GNOME_StickyNotesApplet.xml",
+			NULL, stickynotes_applet_menu_verbs,
+			applet);
 
 	if (panel_applet_get_locked_down (panel_applet)) {
 		BonoboUIComponent *popup_component;
@@ -361,54 +441,113 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 	g_object_unref(pixbuf2);
 }
 
-void stickynotes_applet_update_prefs(void)
+void
+stickynotes_applet_update_prefs (void)
 {
-	gint height, click_behavior;
+	int height, click_behavior;
 	gboolean sys_color, sys_font, sticky, force_default;
-	gchar *font_str;
-	GdkColor color;
-	gint width = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL);
+	char *font_str;
+	char *color_str, *font_color_str;
+	GdkColor color, font_color;
+	
+	gint width = gconf_client_get_int(stickynotes->gconf,
+			GCONF_PATH "/defaults/width", NULL);
 
 	width = MAX (width, 1);
-	height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
+	height = gconf_client_get_int (stickynotes->gconf,
+			GCONF_PATH "/defaults/height", NULL);
 	height = MAX (height, 1);
 
-	sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
-	sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
-	click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
-	sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
-	force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
-	font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
+	sys_color = gconf_client_get_bool (stickynotes->gconf,
+			GCONF_PATH "/settings/use_system_color", NULL);
+	sys_font = gconf_client_get_bool (stickynotes->gconf,
+			GCONF_PATH "/settings/use_system_font", NULL);
+	click_behavior = gconf_client_get_int (stickynotes->gconf,
+			GCONF_PATH "/settings/click_behavior", NULL);
+	sticky = gconf_client_get_bool (stickynotes->gconf,
+			GCONF_PATH "/settings/sticky", NULL);
+	force_default = gconf_client_get_bool (stickynotes->gconf,
+			GCONF_PATH "/settings/force_default", NULL);
+	font_str = gconf_client_get_string (stickynotes->gconf,
+			GCONF_PATH "/defaults/font", NULL);
 
 	if (!font_str)
-		font_str = g_strdup ("Sans 10");
-	
 	{
-		gchar *color_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL);
-		if (!color_str)
-			color_str = g_strdup ("#FFFF00");
-		gdk_color_parse(color_str, &color);
-		g_free(color_str);
+		g_free (font_str);
+		font_str = g_strdup ("Sans 10");
 	}
 
-	gtk_adjustment_set_value(stickynotes->w_prefs_width, width);
-	gtk_adjustment_set_value(stickynotes->w_prefs_height, height);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(stickynotes->w_prefs_sys_color), sys_color);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(stickynotes->w_prefs_sys_font), sys_font);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(stickynotes->w_prefs_click), click_behavior);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(stickynotes->w_prefs_sticky), sticky);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(stickynotes->w_prefs_force), force_default);
-
-	gnome_color_picker_set_i16(GNOME_COLOR_PICKER(stickynotes->w_prefs_color), color.red, color.green, color.blue, 65535);
-	gnome_font_picker_set_font_name(GNOME_FONT_PICKER(stickynotes->w_prefs_font), font_str);
-
-	if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "color_label"), !sys_color);
-		gtk_widget_set_sensitive(stickynotes->w_prefs_color, !sys_color);
+	color_str = gconf_client_get_string (stickynotes->gconf,
+			GCONF_PATH "/defaults/color", NULL);
+	if (!color_str)
+	{
+		g_free (color_str);
+		color_str = g_strdup ("#ECF833");
 	}
-	if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL)) {
-		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "font_label"), !sys_font);
-		gtk_widget_set_sensitive(stickynotes->w_prefs_font, !sys_font);
+	font_color_str = gconf_client_get_string (stickynotes->gconf,
+			GCONF_PATH "/defaults/font_color", NULL);
+	if (!font_color_str)
+	{
+		g_free (font_color_str);
+		font_color_str = g_strdup ("#000000");
+	}
+
+	gdk_color_parse (color_str, &color);
+	g_free (color_str);
+
+	gdk_color_parse (font_color_str, &font_color);
+	g_free (font_color_str);
+
+	gtk_adjustment_set_value (stickynotes->w_prefs_width, width);
+	gtk_adjustment_set_value (stickynotes->w_prefs_height, height);
+	gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (stickynotes->w_prefs_sys_color),
+			sys_color);
+	gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON(stickynotes->w_prefs_sys_font),
+			sys_font);
+	gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (stickynotes->w_prefs_sticky),
+			sticky);
+	gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (stickynotes->w_prefs_force),
+			force_default);
+
+	gtk_color_button_set_color (
+			GTK_COLOR_BUTTON (stickynotes->w_prefs_color), &color);
+	gtk_color_button_set_color (
+			GTK_COLOR_BUTTON (stickynotes->w_prefs_font_color),
+			&font_color);
+	gtk_font_button_set_font_name (
+			GTK_FONT_BUTTON (stickynotes->w_prefs_font), font_str);
+	g_free (font_str);
+
+	if (gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/color", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+				stickynotes->prefs, "color_label"),
+				!sys_color);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_color,
+				!sys_color);
+	}
+	if (gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/font_color", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+				stickynotes->prefs, "font_color_label"),
+				!sys_color);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
+				!sys_color);
+	}
+	if (gconf_client_key_is_writable (stickynotes->gconf,
+				GCONF_PATH "/defaults/font", NULL))
+	{
+		gtk_widget_set_sensitive (glade_xml_get_widget (
+				stickynotes->prefs, "font_label"),
+				!sys_font);
+		gtk_widget_set_sensitive (stickynotes->w_prefs_font,
+				!sys_font);
 	}
 }
 
@@ -444,40 +583,34 @@ void stickynotes_applet_update_menus(void)
 	}
 }
 
-void stickynotes_applet_update_tooltips(void)
+void
+stickynotes_applet_update_tooltips (void)
 {
-	gint num = g_list_length(stickynotes->notes);
-	gchar *tooltip = g_strdup_printf(ngettext("%s\n%d note", "%s\n%d notes", num), _("Sticky Notes"), num);
+	int i;
+	int num;
+	char *tooltip, *no_notes;
+	StickyNotesApplet *applet;
+	GList *l;
+	
+	num = g_list_length (stickynotes->notes);
+	
+	no_notes = g_strdup_printf (ngettext ("%d note", "%d notes", num), num);
+	tooltip = g_strdup_printf ("%s\n%s", _("Sticky Notes"), no_notes);
 
-	gint i;	
-	for (i = 0; i < g_list_length(stickynotes->applets); i++) {
-		StickyNotesApplet *applet = g_list_nth_data(stickynotes->applets, i);
-		gtk_tooltips_set_tip(stickynotes->tooltips, applet->w_applet, tooltip, NULL);
+	for (l = stickynotes->applets; l; l = l->next)
+	{
+		applet = l->data;
+		gtk_tooltips_set_tip (stickynotes->tooltips,
+				applet->w_applet, tooltip, NULL);
+	
+		if (applet->menu_tip)
+			gtk_label_set_text (GTK_LABEL (gtk_bin_get_child (
+						GTK_BIN (applet->menu_tip))),
+				no_notes);
+		if (applet->menu_show)
+			gtk_widget_set_sensitive (applet->menu_show, num);
 	}
 
-	g_free(tooltip);
-}
-
-void stickynotes_applet_do_default_action(GdkScreen *screen)
-{
-	StickyNotesDefaultAction click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
-
-	gboolean visible = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
-	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
-
-	switch (click_behavior) {
-		case STICKYNOTES_NEW:
-			stickynotes_add(screen);
-			break;
-
-		case STICKYNOTES_SET_VISIBLE:
-			if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL))
-				gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", !visible, NULL);
-			break;
-
-		case STICKYNOTES_SET_LOCKED:
-			if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL))
-				gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", !locked, NULL);
-			break;
-	}
+	g_free (tooltip);
+	g_free (no_notes);
 }
