@@ -28,9 +28,13 @@ gboolean applet_key_cb(GtkWidget *widget, GdkEventKey *event, StickyNotesApplet
 gboolean applet_cross_cb(GtkWidget *widget, GdkEventCrossing *event, StickyNotesApplet *applet);
 gboolean applet_focus_cb(GtkWidget *widget, GdkEventFocus *event, StickyNotesApplet *applet);
 gboolean applet_save_cb(StickyNotesApplet *applet);
-gboolean applet_change_size_cb(GtkWidget *widget, gint size, StickyNotesApplet *applet);
-gboolean applet_change_bg_cb(PanelApplet *panel_applet, PanelAppletBackgroundType type, GdkColor *color, GdkPixmap *pixmap,
-			     StickyNotesApplet *applet);
+void applet_change_orient_cb(PanelApplet *panel_applet, PanelAppletOrient orient, StickyNotesApplet *applet);
+void applet_size_allocate_cb(GtkWidget *widget, GtkAllocation *allocation, StickyNotesApplet *applet);
+void applet_change_bg_cb (PanelApplet *panel_applet,
+				 PanelAppletBackgroundType type,
+				 GdkColor *color,
+                     		 GdkPixmap *pixmap,
+                     		 StickyNotesApplet *applet);
 void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet);
 
 /* Callbacks for sticky notes applet menu */
@@ -44,8 +48,8 @@ void menu_about_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gcha
 
 /* Callbacks for sticky notes preferences dialog */
 void preferences_save_cb(gpointer data);
-void preferences_color_cb(GnomeColorPicker *cp, guint r, guint g, guint b, guint a, gpointer data);
-void preferences_font_cb(GnomeFontPicker *fp, gchar *font_str, gpointer data);
+void preferences_color_cb (GtkWidget *button, gpointer data);
+void preferences_font_cb (GtkWidget *button, gpointer data);
 void preferences_apply_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer data);
 void preferences_response_cb(GtkDialog *dialog, gint response, gpointer data);
 gboolean preferences_delete_cb(GtkWidget *widget, GdkEvent *event, gpointer data);
